@@ -15,7 +15,7 @@ TEST_DATA_FOLDER = path = os.path.abspath(
 
 
 @pytest.mark.parametrize("input_bam, model_exp", [
-    [TEST_DATA_FOLDER + "mas15_test_input.bam", "mas15v2"],
+    [TEST_DATA_FOLDER + "mas15_test_input.bam", "mas_15_sc_10x5p_single_none"],
 ])
 def test_peek_from_file(tmpdir, input_bam, model_exp):
 
@@ -32,7 +32,7 @@ def test_peek_from_file(tmpdir, input_bam, model_exp):
 
 
 @pytest.mark.parametrize("input_bam, model_exp", [
-    [TEST_DATA_FOLDER + "mas15_test_input.bam", "mas15v2"],
+    [TEST_DATA_FOLDER + "mas15_test_input.bam", "mas_15_sc_10x5p_single_none"],
 ])
 def test_peek_from_pipe(tmpdir, input_bam, model_exp):
     actual_file = tmpdir.join(f"peek_actual_out.{model_exp}.pipe.txt")
